@@ -8,7 +8,6 @@ as well as write data out in a variety of formats
 #===============================================================================
 
 import numpy as np
-import sys
 from pathlib import Path
 
 from .flags import verbose, progress_bars
@@ -50,12 +49,13 @@ def read_output(f, start=None, stop=None):
     #start (optional): the line to actually start reading in data
     #stop (optional): the line to stop reading in data
 
+    flen = 0 #allows this to be used outside of the next if statement's scope
     if progress_bars:
         flen = file_len(f)
         #properly adjust for length change based on start and stop points
-        if start:
+        if start is not None:
             flen -= start
-        if stop:
+        if stop is not None:
             flen -= stop
     if verbose:
         print('\nReading in data from ' + str(f) + '...')
@@ -73,13 +73,14 @@ def read_output(f, start=None, stop=None):
 
     #if start is specified,
     #skip lines until we're at the starting line
-    if start:
+    if start is not None:
         while j < start:
             f.readline()
             j += 1
 
     j = 0 #reset line counter for progress bar
     for line in f:
+
         line = line.strip().split(',')
         i = 0
         while i < len(line) - 1: #this grabs l, b, r data even though that is calculated from x, y, z in the Timestep class implementation
@@ -88,21 +89,24 @@ def read_output(f, start=None, stop=None):
             i += 1
         j += 1
 
-        #stop reading in lines if we're past the stop setting
-        if stop:
-            if j >= stop:
-                break
-
         if progress_bars:
             progress_bar(j, flen)
 
+        #stop reading in lines if we're past the stop setting
+        if stop is not None:
+            if j >= stop:
+                break
+        else:
+            continue  # only executed if the inner loop did NOT break
+        break #only executed if the inner loop DID break
+
     #return the Timestep class using the array dictionary we built
     if verbose:
         print('\n'+ str(len(array_dict[1])) + ' objects read in')
-        sys.stdout.write('\rConverting data...')
+        print('\rConverting data...', end='')
     d = Timestep(typ=array_dict[0], id_val=array_dict[1], x=array_dict[2], y=array_dict[3], z=array_dict[4], vx=array_dict[8], vy=array_dict[9], vz=array_dict[10], mass=array_dict[11], center_of_mass=comass, center_of_momentum=comom)
     if verbose:
-        sys.stdout.write('done\n')
+        print('done')
 
     f.close()
 
@@ -141,10 +145,10 @@ def read_input(f):
     #return the Timestep class using the array dictionary we built
     if verbose:
         print('\n'+ str(len(array_dict[1])) + ' objects read in')
-        sys.stdout.write('\rConverting data...')
+        print('\rConverting data...', end='')
     d = Timestep(typ=array_dict[0], id_val=array_dict[1], x=array_dict[2], y=array_dict[3], z=array_dict[4], vx=array_dict[5], vy=array_dict[6], vz=array_dict[7], mass=array_dict[8], center_of_mass=[0,0,0], center_of_momentum=[0,0,0])
     if verbose:
-        sys.stdout.write('done\n')
+        print('done')
 
     f.close()
 
@@ -193,7 +197,7 @@ def make_nbody_input(t, f, recenter=True):
     i = 0
 
     while i < len(t):
-        f.write('\n{} {} {:.6f} {:.6f} {:.6f} {:.6f} {:.6f} {:.6f} {} '.format(1, t.id[i], t.x[i], t.y[i], t.z[i], t.vx[i], t.vy[i], t.vz[i], t.mass[i]))
+        f.write('\n{}\t{}\t{:.6f}\t{:.6f}\t{:.6f}\t{:.6f}\t{:.6f}\t{:.6f}\t{} '.format(1, t.id[i], t.x[i], t.y[i], t.z[i], t.vx[i], t.vy[i], t.vz[i], t.mass[i]))
         #f.write('\n'+str(1)+' '+str(t.id[i])+' '+str(t.x[i])+' '+str(t.y[i])+' '+str(t.z[i])+' '+\
         #        str(t.vx[i])+' '+str(t.vy[i])+' '+str(t.vz[i])+' '+str(t.mass[i]))
         if progress_bars:
