@@ -18,9 +18,9 @@ import random
 import galpy.potential
 
 #mwahpy imports
-from .mwahpy_glob import struct_to_sol
+from .mwahpy_glob import struct_to_sol, progress_bar
 from .flags import auto_update, verbose
-from .plot import scatter, hist2d
+from .plot import scatter, trace_particle, hist, hist2d, fancy_plot
 from .pot import mwahpy_default_pot, energy_offset
 from .coords import get_rvpm
 
@@ -29,7 +29,7 @@ from .coords import get_rvpm
 #===============================================================================
 
 basic_quantity_list = ['msol', 'l', 'b', 'ra', 'dec', 'phi', 'theta', 'dist', 'lx', 'ly', 'lz', 'lperp', 'ltot', 'r', 'R', 'vlos', 'vgsr', 'vrad', 'vrot', 'vR', 'dist_from_com']
-rvpm_quantity_list = ['rv', 'pmra', 'pmdec',  'pmtot', 'vtan']
+rvpm_quantity_list = ['pmra', 'pmdec',  'pmtot', 'vtan']
 energy_quantity_list = ['PE', 'KE', 'energy']
 
 #===============================================================================
@@ -217,6 +217,9 @@ class Timestep():
     def update(self, force=False):
         #only update the necessary attributes based on what changed
         #if force==True, then force updating everything. Should be only rarely needed
+        if verbose:
+            print('Updating data for new frame...')
+
         if force:
             self.changed_pos = True
             self.changed_vel = True
@@ -239,6 +242,9 @@ class Timestep():
         changed_pos = False
         changed_vel = False
 
+        if verbose:
+            print('Done updating')
+
     #creates a deep copy of the Timestep object
     #this can't be done by iterating over the object, since comass etc. have to be copied as well
     def copy(self):
@@ -307,7 +313,8 @@ class Timestep():
         self.vgsr = ((self.x+8)*self.vx + self.y*self.vy + self.x*self.vz)/self.dist
         self.vlos = self.vgsr - 10.1*np.cos(self.b*np.pi/180)*np.cos(self.l*np.pi/180) - 224*np.cos(self.b*np.pi/180)*np.sin(self.l*np.pi/180) - 6.7*np.sin(self.b*np.pi/180)
         self.vrad = (self.x*self.vx + self.y*self.vy + self.z*self.vz)/self.r
-        self.vrot = self.lz/(self.x**2 + self.y**2)**0.5
+        self.vrot = self.lz/(self.x**2 + self.y**2)**0.5 #should have a factor of cos(theta) I think? Need to define what I mean exactly by this quantity
+                                                         #should also make a polar velocity if I'm going to do that
         self.vR = (self.x*self.vx + self.y*self.vy)/self.R
 
         #relative information
@@ -470,6 +477,9 @@ class Timestep():
     #   overall velocities when they relax from unstable virial equilibrium ICs
     #Conserves the physics of the system under a change of reference frame
     def recenter(self):
+        if verbose:
+            print('Recentering the data on the centers of mass and momentum...', end='')
+
         #center the positions of the particles
         self.x = self.x - self.center_of_mass[0]
         self.y = self.y - self.center_of_mass[1]
@@ -480,6 +490,9 @@ class Timestep():
         self.vy = self.vy - self.center_of_momentum[1]
         self.vz = self.vz - self.center_of_momentum[2]
 
+        if verbose:
+            print('done')
+
         if auto_update:
             self.update()
 
@@ -548,9 +561,19 @@ class Timestep():
     def scatter(self, x, y, **kwargs):
         scatter(self, x, y, **kwargs)
 
+    def trace_particle(self, id, x, y, **kwargs):
+        trace_particle(self, id, x, y, **kwargs)
+
+    def hist(self, x, **kwargs):
+        hist(self, x, **kwargs)
+
     def hist2d(self, x, y, **kwargs):
         hist2d(self, x, y, **kwargs)
 
+    #uses kwargs for plt.plot()
+    def fancy_plot(self, x, y, **kwargs):
+        fancy_plot(self, x, y, **kwargs)
+
     #---------------------------------------------------------------------------
     # MISCELLANEOUS
     #---------------------------------------------------------------------------
@@ -680,12 +703,15 @@ def get_self_energies(t):
     pot_energies = []
 
     #compute the self gravitational potential energy of each particle
+    i = 0 #tracking
     for x1, y1, z1 in zip(t.x, t.y, t.z):
-        pe = 0
-        for x2, y2, z2, m in zip(t.x, t.y, t.z, t.mass):
-            r = ((x1 - x2)**2 + (y1 - y2)**2 + (z1 - z2)**2)**0.5
-            pe -= gc * m / r #potential energy is negative
+        progress_bar(i, len(t.x))
+        i += 1
+
+        r = ((x1 - t.x)**2 + (y1 - t.y)**2 + (z1 - t.z)**2)**0.5
+        pe = np.sum(-1 * gc * t.mass[r != 0] / r[r != 0]) #potential energy is negative, remove where r == 0
         pot_energies.append(pe)
+
     pot_energies = np.array(pot_energies) #do it this way because np.append is horrendously slow
 
     #compute the kinetic energy of each particle (within reference frame of
